@@ -1,7 +1,7 @@
 sub Mojo::Webqq::Client::_get_vfwebqq {
     my $self = shift;
     $self->info("获取数据验证参数...\n");
-    my $api_url = 'http://s.web2.qq.com/api/getvfwebqq';
+    my $api_url = 'https://s.web2.qq.com/api/getvfwebqq';
     my @query_string = (
         ptwebqq    =>  $self->ptwebqq,
         clientid   =>  $self->clientid,
@@ -9,7 +9,7 @@ sub Mojo::Webqq::Client::_get_vfwebqq {
         t          =>  time(),
     );  
     my $headers = {
-        Referer => 'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
+        Referer => 'https://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
         json    => 1,
         ua_request_timeout => 10,
         ua_retry_times => 3,
