@@ -2,8 +2,8 @@ sub Mojo::Webqq::Model::get_single_long_nick{
     my $self = shift;
     my $uin = shift;
     
-    my $api_url = 'http://s.web2.qq.com/api/get_single_long_nick2';
-    my $headers  = {Referer=>'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',json=>1};
+    my $api_url = 'https://s.web2.qq.com/api/get_single_long_nick2';
+    my $headers  = {Referer=>'https://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',json=>1};
     my @query_string = (
         tuin            =>  $uin,
         vfwebqq         =>  $self->vfwebqq,
