@@ -102,7 +102,7 @@ sub call {
         my $key_word = $1;$key_word=~s/\s+//;
         my $reply = $reply[int rand($#reply+1)];
         $reply=~s/%/$key_word/g;
-        $client->reply_message($msg,$reply,sub{$_[1]->from("bot")}) if $reply;
+        $msg->reply($reply,sub{$_[1]->from("bot")}) if $reply;
     });
 }
 1;
